#!/usr/bin/env python3

from datetime import datetime, timedelta
from pathlib import Path
from shutil import rmtree

import click
from gitignore_parser import parse_gitignore


@click.command(no_args_is_help=True)
@click.option('-q', '--quiet',
              is_flag=True,
              help='quiet output')
@click.option('--dry-run',
              is_flag=True)
@click.option('-d', '--day',
              type=click.IntRange(0),
              default=3,
              help='削除対象となる期日',
              show_default=True)
@click.argument('targetdir',
                type=click.Path(exists=True))
def ctx(targetdir, day, dry_run, quiet):
    '''
    tmpディレクトリの中身お掃除君

    \b
    <TARGETDIR>で指定されたディレクトリの中身をせっせとお掃除してくれるかわいいやつ。
    自分がよく ~/document/tmp/ とか雑にディレクトリ作ってしまうので、それのお掃除用に生まれた

    <TARGETDIR>/.rmtmpignore のファイルに gitignore と同様の書式でファイルを指定することで、
    削除対象から明示的に外すことができる。
    '''
    target = Path(targetdir).expanduser()
    if not quiet:
        click.echo(f'target is [{target}]')
    rmtmpignore = Path(target, '.rmtmpignore')
    target_files = get_files(target)
    if rmtmpignore.exists() and not quiet:
        click.echo(f'find [{rmtmpignore}]')
    target_files = filter_files(target_files, day, rmtmpignore)
    rm_files(target_files, dry_run, quiet)


def get_files(target):
    files = [f for f in target.iterdir()]
    return files


def filter_files(target_files, day, rmtmpignore):
    files = []
    matches = None
    if rmtmpignore.exists():
        matches = parse_gitignore(rmtmpignore)
        try:
            target_files.pop(target_files.index(rmtmpignore))
        except Exception as error:
            click.echo(f'WARN: {error}', err=True)
    for file in target_files:
        if matches is not None and matches(file):
            continue
        mtime = datetime.fromtimestamp(file.stat().st_mtime)
        today = datetime.now()
        if today - mtime < timedelta(days=day):
            continue
        files.append(file)
    return files


def rm_files(target_files, dry_run, quiet):
    for file in target_files:
        if dry_run is True:
            click.echo(file)
        else:
            try:
                if not quiet:
                    click.echo(f'rm [{file}]')
                if file.is_dir():
                    rmtree(file)
                else:
                    file.unlink()
            except Exception as error:
                msg = f'{file} remove failur [{error}]'
                click.echo(msg, err=True)



#!/usr/bin/env python3

from pathlib import Path

import click
from pikepdf import Pdf


@click.group()
def ctx():
    '''
    \b
    PDF file をあれやこれやしたいがためのコマンド
    '''


@ctx.command()
@click.option('password', '-p',
              help='decrypt password',
              prompt=True,
              hide_input=True)
@click.option('--output', '-o',
              help='output decrypt pdf filename [default: <pdffile>.unlock.pdf]',  # noqa: E501
              type=click.Path())
@click.option('--force', '-f',
              help='<output> override',
              is_flag=True)
@click.argument('pdffile',
                required=True,
                type=click.Path(exists=True))
def unlock(pdffile, output, password, force):
    '''
    パスワード付きPDFファイルを、パスワードなしPDFファイルにコピーする
    '''
    click.echo(f'input pdf file: {pdffile}')
    lockpdf = Pdf.open(pdffile, password=password)
    unlockpdf = Pdf.new()
    unlockpdf.pages.extend(lockpdf.pages)
    if output is None:
        output = Path(pdffile).with_suffix('.unlock.pdf')
    else:
        output = Path(output)
    if output.exists() or not force:
        click.confirm(f'{output} is exists. Do you want to override?',
                      default=True,
                      abort=True,
                      show_default=True)

    unlockpdf.save(output)
    click.echo(f'output pdf file: {output}')



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['shuncommands']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0,<9.0', 'gitignore-parser>=0.0.8,<0.0.9', 'pikepdf>=4.1.0,<5.0.0']

entry_points = \
{'console_scripts': ['pdftool = shuncommands.pdftool:ctx',
                     'rmtmp = shuncommands.rmtmp:ctx']}

setup_kwargs = {
    'name': 'shuncommands',
    'version': '1.0.4a2',
    'description': 'mypaceshun usefull commands',
    'long_description': '[![Tests](https://github.com/mypaceshun/shuncommands/actions/workflows/test.yml/badge.svg)](https://github.com/mypaceshun/shuncommands/actions/workflows/test.yml)\n# shuncommands\n\nmy usefull commands\n\n\n# install\n\n```\n$ pip install shuncommands\n```\n\n# install commands\n\n  * rmtmp\n  * pdftool\n\n# rmtmp Usage\n\n```\nUsage: rmtmp [OPTIONS] TARGETDIR\n\n  tmpディレクトリの中身お掃除君\n\n  <TARGETDIR>で指定されたディレクトリの中身をせっせとお掃除してくれるかわいいやつ。\n  自分がよく ~/document/tmp/ とか雑にディレクトリ作ってしまうので、それのお掃除用に生まれた\n\n  <TARGETDIR>/.rmtmpignore のファイルに gitignore と同様の書式でファイルを指定することで、\n  削除対象から明示的に外すことができる。\n\nOptions:\n  -q, --quiet              quiet output\n  --dry-run\n  -d, --day INTEGER RANGE  削除対象となる期日  [default: 3; x>=0]\n  --help                   Show this message and exit.\n```\n\n# pdftool usage\n\n```\nUsage: pdftool [OPTIONS] COMMAND [ARGS]...\n\n  PDF file をあれやこれやしたいがためのコマンド\n\nOptions:\n  --help  Show this message and exit.\n\nCommands:\n  unlock  パスワード付きPDFファイルを、パスワードなしPDFファイルにコピーする\n```\n',
    'author': 'KAWAI Shun',
    'author_email': 'mypaceshun@gmail.com',
    'maintainer': 'KAWAI Shun',
    'maintainer_email': 'mypaceshun@gmail.com',
    'url': 'https://github.com/mypaceshun/shuncommands',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
